==> italc_1.0.7.orig.tar.gz: italc-1.0.7/lib/resources/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="51"/>
        <source>UPL (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</source>
        <translation>NML (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</translation>
    </message>
    <message>
        <location filename="../src/local_system.cpp" line="704"/>
        <source>iTALC-snapshots</source>
        <translation type="unfinished">Captures iTALC</translation>
    </message>
</context>
<context>
    <name>ivsConnection</name>
    <message>
        <location filename="../src/ivs_connection.cpp" line="307"/>
        <source>Snapshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ivs_connection.cpp" line="309"/>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>localSystem::QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="621"/>
        <source>iTALC-snapshots</source>
        <translation type="obsolete">Captures iTALC</translation>
    </message>
</context>
<context>
    <name>lockWidget</name>
    <message>
        <location filename="../src/lock_widget.cpp" line="57"/>
        <source>screen lock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>messageBox</name>
    <message>
        <location filename="../src/messagebox.cpp" line="75"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>vncView</name>
    <message>
        <location filename="../src/vncview.cpp" line="55"/>
        <source>Establishing connection to %1 ...</source>
        <translation>Établissement de la connexion à %1 ...</translation>
    </message>
</context>
</TS>

==> italc_1.0.9~rc3.orig.tar.gz: italc-1.0.9~rc3/lib/resources/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="52"/>
        <source>UPL (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</source>
        <translation>NML (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</translation>
    </message>
    <message>
        <location filename="../src/local_system.cpp" line="642"/>
        <source>iTALC-snapshots</source>
        <translation>Captures iTALC</translation>
    </message>
</context>
<context>
    <name>ivsConnection</name>
    <message>
        <location filename="../src/ivs_connection.cpp" line="308"/>
        <source>Snapshot</source>
        <translation>Capture</translation>
    </message>
    <message>
        <location filename="../src/ivs_connection.cpp" line="310"/>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation>Impossible de prendre une capture : le répertoire %1 n&apos;existe pas et ne peut être créé.</translation>
    </message>
</context>
<context>
    <name>lockWidget</name>
    <message>
        <location filename="../src/lock_widget.cpp" line="69"/>
        <source>screen lock</source>
        <translation>ver. écran</translation>
    </message>
</context>
<context>
    <name>messageBox</name>
    <message>
        <location filename="../src/messagebox.cpp" line="76"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>vncView</name>
    <message>
        <location filename="../src/vncview.cpp" line="61"/>
        <source>Establishing connection to %1 ...</source>
        <translation>Établissement de la connexion à %1 ...</translation>
    </message>
</context>
</TS>
